import type { NextSeoProps } from "next-seo";
import type { Item } from "nextra/normalize-pages";
import type { FC, ReactNode } from "react";
import { z } from "zod";
import type { NavBarProps } from "./components/navbar";
import type { TOCProps } from "./components/toc";
export declare const DEFAULT_LOCALE = "fr";
export declare const IS_BROWSER: boolean;
export declare const themeSchema: z.ZodObject<{
    banner: z.ZodObject<{
        dismissible: z.ZodBoolean;
        key: z.ZodString;
        text: z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>;
    }, "strict", z.ZodTypeAny, {
        key: string;
        dismissible: boolean;
        text?: ReactNode | FC;
    }, {
        key: string;
        dismissible: boolean;
        text?: ReactNode | FC;
    }>;
    chat: z.ZodObject<{
        icon: z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>;
        link: z.ZodOptional<z.ZodString>;
    }, "strict", z.ZodTypeAny, {
        icon?: ReactNode | FC;
        link?: string | undefined;
    }, {
        icon?: ReactNode | FC;
        link?: string | undefined;
    }>;
    components: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodType<FC, z.ZodTypeDef, FC>>>;
    darkMode: z.ZodBoolean;
    direction: z.ZodEnum<["ltr", "rtl"]>;
    docsRepositoryBase: z.ZodString;
    editLink: z.ZodObject<{
        component: z.ZodType<FC<{
            children: ReactNode;
            className?: string | undefined;
            filePath?: string | undefined;
        }>, z.ZodTypeDef, FC<{
            children: ReactNode;
            className?: string | undefined;
            filePath?: string | undefined;
        }>>;
        text: z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>;
    }, "strict", z.ZodTypeAny, {
        component: FC<{
            children: ReactNode;
            className?: string | undefined;
            filePath?: string | undefined;
        }>;
        text?: ReactNode | FC;
    }, {
        component: FC<{
            children: ReactNode;
            className?: string | undefined;
            filePath?: string | undefined;
        }>;
        text?: ReactNode | FC;
    }>;
    faviconGlyph: z.ZodOptional<z.ZodString>;
    feedback: z.ZodObject<{
        content: z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>;
        labels: z.ZodString;
        useLink: z.ZodFunction<z.ZodTuple<[], z.ZodUnknown>, z.ZodString>;
    }, "strict", z.ZodTypeAny, {
        labels: string;
        useLink: (...args: unknown[]) => string;
        content?: ReactNode | FC;
    }, {
        labels: string;
        useLink: (...args: unknown[]) => string;
        content?: ReactNode | FC;
    }>;
    footer: z.ZodObject<{
        component: z.ZodType<ReactNode | FC<{
            menu: boolean;
        }>, z.ZodTypeDef, ReactNode | FC<{
            menu: boolean;
        }>>;
        text: z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>;
    }, "strict", z.ZodTypeAny, {
        component?: ReactNode | FC<{
            menu: boolean;
        }>;
        text?: ReactNode | FC;
    }, {
        component?: ReactNode | FC<{
            menu: boolean;
        }>;
        text?: ReactNode | FC;
    }>;
    gitTimestamp: z.ZodType<ReactNode | FC<{
        timestamp: Date;
    }>, z.ZodTypeDef, ReactNode | FC<{
        timestamp: Date;
    }>>;
    head: z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>;
    i18n: z.ZodArray<z.ZodObject<{
        direction: z.ZodOptional<z.ZodEnum<["ltr", "rtl"]>>;
        locale: z.ZodString;
        text: z.ZodString;
    }, "strict", z.ZodTypeAny, {
        locale: string;
        text: string;
        direction?: "ltr" | "rtl" | undefined;
    }, {
        locale: string;
        text: string;
        direction?: "ltr" | "rtl" | undefined;
    }>, "many">;
    main: z.ZodOptional<z.ZodType<FC<{
        children: ReactNode;
    }>, z.ZodTypeDef, FC<{
        children: ReactNode;
    }>>>;
    navbar: z.ZodObject<{
        component: z.ZodType<ReactNode | FC<NavBarProps>, z.ZodTypeDef, ReactNode | FC<NavBarProps>>;
        extraContent: z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>;
    }, "strict", z.ZodTypeAny, {
        component?: ReactNode | FC<NavBarProps>;
        extraContent?: ReactNode | FC;
    }, {
        component?: ReactNode | FC<NavBarProps>;
        extraContent?: ReactNode | FC;
    }>;
    navigation: z.ZodUnion<[z.ZodBoolean, z.ZodObject<{
        next: z.ZodBoolean;
        prev: z.ZodBoolean;
    }, "strict", z.ZodTypeAny, {
        next: boolean;
        prev: boolean;
    }, {
        next: boolean;
        prev: boolean;
    }>]>;
    nextThemes: z.ZodObject<{
        defaultTheme: z.ZodString;
        forcedTheme: z.ZodOptional<z.ZodString>;
        storageKey: z.ZodString;
    }, "strict", z.ZodTypeAny, {
        defaultTheme: string;
        storageKey: string;
        forcedTheme?: string | undefined;
    }, {
        defaultTheme: string;
        storageKey: string;
        forcedTheme?: string | undefined;
    }>;
    notFound: z.ZodObject<{
        content: z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>;
        labels: z.ZodString;
    }, "strict", z.ZodTypeAny, {
        labels: string;
        content?: ReactNode | FC;
    }, {
        labels: string;
        content?: ReactNode | FC;
    }>;
    primaryHue: z.ZodUnion<[z.ZodNumber, z.ZodObject<{
        dark: z.ZodNumber;
        light: z.ZodNumber;
    }, "strict", z.ZodTypeAny, {
        light: number;
        dark: number;
    }, {
        light: number;
        dark: number;
    }>]>;
    project: z.ZodObject<{
        icon: z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>;
        link: z.ZodOptional<z.ZodString>;
    }, "strict", z.ZodTypeAny, {
        icon?: ReactNode | FC;
        link?: string | undefined;
    }, {
        icon?: ReactNode | FC;
        link?: string | undefined;
    }>;
    search: z.ZodObject<{
        component: z.ZodType<ReactNode | FC<{
            className?: string | undefined;
            directories: Item[];
        }>, z.ZodTypeDef, ReactNode | FC<{
            className?: string | undefined;
            directories: Item[];
        }>>;
        emptyResult: z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>;
        error: z.ZodUnion<[z.ZodString, z.ZodFunction<z.ZodTuple<[], z.ZodUnknown>, z.ZodString>]>;
        loading: z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>;
        placeholder: z.ZodUnion<[z.ZodString, z.ZodFunction<z.ZodTuple<[], z.ZodUnknown>, z.ZodString>]>;
    }, "strict", z.ZodTypeAny, {
        placeholder: (string | ((...args: unknown[]) => string)) & (string | ((...args: unknown[]) => string) | undefined);
        error: (string | ((...args: unknown[]) => string)) & (string | ((...args: unknown[]) => string) | undefined);
        component?: ReactNode | FC<{
            className?: string | undefined;
            directories: Item[];
        }>;
        emptyResult?: ReactNode | FC;
        loading?: ReactNode | FC;
    }, {
        placeholder: (string | ((...args: unknown[]) => string)) & (string | ((...args: unknown[]) => string) | undefined);
        error: (string | ((...args: unknown[]) => string)) & (string | ((...args: unknown[]) => string) | undefined);
        component?: ReactNode | FC<{
            className?: string | undefined;
            directories: Item[];
        }>;
        emptyResult?: ReactNode | FC;
        loading?: ReactNode | FC;
    }>;
    serverSideError: z.ZodObject<{
        content: z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>;
        labels: z.ZodString;
    }, "strict", z.ZodTypeAny, {
        labels: string;
        content?: ReactNode | FC;
    }, {
        labels: string;
        content?: ReactNode | FC;
    }>;
    sidebar: z.ZodObject<{
        autoCollapse: z.ZodOptional<z.ZodBoolean>;
        defaultMenuCollapseLevel: z.ZodNumber;
        titleComponent: z.ZodType<ReactNode | FC<{
            title: string;
            type: string;
            route: string;
        }>, z.ZodTypeDef, ReactNode | FC<{
            title: string;
            type: string;
            route: string;
        }>>;
        toggleButton: z.ZodBoolean;
    }, "strict", z.ZodTypeAny, {
        defaultMenuCollapseLevel: number;
        toggleButton: boolean;
        autoCollapse?: boolean | undefined;
        titleComponent?: ReactNode | FC<{
            title: string;
            type: string;
            route: string;
        }>;
    }, {
        defaultMenuCollapseLevel: number;
        toggleButton: boolean;
        autoCollapse?: boolean | undefined;
        titleComponent?: ReactNode | FC<{
            title: string;
            type: string;
            route: string;
        }>;
    }>;
    themeSwitch: z.ZodObject<{
        component: z.ZodType<ReactNode | FC<{
            lite?: boolean | undefined;
            className?: string | undefined;
        }>, z.ZodTypeDef, ReactNode | FC<{
            lite?: boolean | undefined;
            className?: string | undefined;
        }>>;
        useOptions: z.ZodUnion<[z.ZodObject<{
            light: z.ZodString;
            dark: z.ZodString;
            system: z.ZodString;
        }, "strict", z.ZodTypeAny, {
            system: string;
            light: string;
            dark: string;
        }, {
            system: string;
            light: string;
            dark: string;
        }>, z.ZodFunction<z.ZodTuple<[], z.ZodUnknown>, z.ZodObject<{
            light: z.ZodString;
            dark: z.ZodString;
            system: z.ZodString;
        }, "strict", z.ZodTypeAny, {
            system: string;
            light: string;
            dark: string;
        }, {
            system: string;
            light: string;
            dark: string;
        }>>]>;
    }, "strict", z.ZodTypeAny, {
        useOptions: ({
            system: string;
            light: string;
            dark: string;
        } | ((...args: unknown[]) => {
            system: string;
            light: string;
            dark: string;
        })) & ({
            system: string;
            light: string;
            dark: string;
        } | ((...args: unknown[]) => {
            system: string;
            light: string;
            dark: string;
        }) | undefined);
        component?: ReactNode | FC<{
            lite?: boolean | undefined;
            className?: string | undefined;
        }>;
    }, {
        useOptions: ({
            system: string;
            light: string;
            dark: string;
        } | ((...args: unknown[]) => {
            system: string;
            light: string;
            dark: string;
        })) & ({
            system: string;
            light: string;
            dark: string;
        } | ((...args: unknown[]) => {
            system: string;
            light: string;
            dark: string;
        }) | undefined);
        component?: ReactNode | FC<{
            lite?: boolean | undefined;
            className?: string | undefined;
        }>;
    }>;
    toc: z.ZodObject<{
        component: z.ZodType<ReactNode | FC<TOCProps>, z.ZodTypeDef, ReactNode | FC<TOCProps>>;
        extraContent: z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>;
        float: z.ZodBoolean;
        headingComponent: z.ZodOptional<z.ZodType<FC<{
            id: string;
            children: string;
        }>, z.ZodTypeDef, FC<{
            id: string;
            children: string;
        }>>>;
        title: z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>;
    }, "strict", z.ZodTypeAny, {
        float: boolean;
        component?: ReactNode | FC<TOCProps>;
        extraContent?: ReactNode | FC;
        headingComponent?: FC<{
            id: string;
            children: string;
        }> | undefined;
        title?: ReactNode | FC;
    }, {
        float: boolean;
        component?: ReactNode | FC<TOCProps>;
        extraContent?: ReactNode | FC;
        headingComponent?: FC<{
            id: string;
            children: string;
        }> | undefined;
        title?: ReactNode | FC;
    }>;
    useNextSeoProps: z.ZodType<() => NextSeoProps | void, z.ZodTypeDef, () => NextSeoProps | void>;
}, "strict", z.ZodTypeAny, {
    banner: {
        key: string;
        dismissible: boolean;
        text?: ReactNode | FC;
    };
    navigation: (boolean | {
        next: boolean;
        prev: boolean;
    }) & (boolean | {
        next: boolean;
        prev: boolean;
    } | undefined);
    search: {
        placeholder: (string | ((...args: unknown[]) => string)) & (string | ((...args: unknown[]) => string) | undefined);
        error: (string | ((...args: unknown[]) => string)) & (string | ((...args: unknown[]) => string) | undefined);
        component?: ReactNode | FC<{
            className?: string | undefined;
            directories: Item[];
        }>;
        emptyResult?: ReactNode | FC;
        loading?: ReactNode | FC;
    };
    footer: {
        component?: ReactNode | FC<{
            menu: boolean;
        }>;
        text?: ReactNode | FC;
    };
    chat: {
        icon?: ReactNode | FC;
        link?: string | undefined;
    };
    darkMode: boolean;
    direction: "ltr" | "rtl";
    docsRepositoryBase: string;
    editLink: {
        component: FC<{
            children: ReactNode;
            className?: string | undefined;
            filePath?: string | undefined;
        }>;
        text?: ReactNode | FC;
    };
    feedback: {
        labels: string;
        useLink: (...args: unknown[]) => string;
        content?: ReactNode | FC;
    };
    i18n: {
        locale: string;
        text: string;
        direction?: "ltr" | "rtl" | undefined;
    }[];
    navbar: {
        component?: ReactNode | FC<NavBarProps>;
        extraContent?: ReactNode | FC;
    };
    nextThemes: {
        defaultTheme: string;
        storageKey: string;
        forcedTheme?: string | undefined;
    };
    notFound: {
        labels: string;
        content?: ReactNode | FC;
    };
    primaryHue: (number | {
        light: number;
        dark: number;
    }) & (number | {
        light: number;
        dark: number;
    } | undefined);
    project: {
        icon?: ReactNode | FC;
        link?: string | undefined;
    };
    serverSideError: {
        labels: string;
        content?: ReactNode | FC;
    };
    sidebar: {
        defaultMenuCollapseLevel: number;
        toggleButton: boolean;
        autoCollapse?: boolean | undefined;
        titleComponent?: ReactNode | FC<{
            title: string;
            type: string;
            route: string;
        }>;
    };
    themeSwitch: {
        useOptions: ({
            system: string;
            light: string;
            dark: string;
        } | ((...args: unknown[]) => {
            system: string;
            light: string;
            dark: string;
        })) & ({
            system: string;
            light: string;
            dark: string;
        } | ((...args: unknown[]) => {
            system: string;
            light: string;
            dark: string;
        }) | undefined);
        component?: ReactNode | FC<{
            lite?: boolean | undefined;
            className?: string | undefined;
        }>;
    };
    toc: {
        float: boolean;
        component?: ReactNode | FC<TOCProps>;
        extraContent?: ReactNode | FC;
        headingComponent?: FC<{
            id: string;
            children: string;
        }> | undefined;
        title?: ReactNode | FC;
    };
    useNextSeoProps: () => NextSeoProps | void;
    components?: Record<string, FC> | undefined;
    faviconGlyph?: string | undefined;
    gitTimestamp?: ReactNode | FC<{
        timestamp: Date;
    }>;
    head?: ReactNode | FC;
    main?: FC<{
        children: ReactNode;
    }> | undefined;
}, {
    banner: {
        key: string;
        dismissible: boolean;
        text?: ReactNode | FC;
    };
    navigation: (boolean | {
        next: boolean;
        prev: boolean;
    }) & (boolean | {
        next: boolean;
        prev: boolean;
    } | undefined);
    search: {
        placeholder: (string | ((...args: unknown[]) => string)) & (string | ((...args: unknown[]) => string) | undefined);
        error: (string | ((...args: unknown[]) => string)) & (string | ((...args: unknown[]) => string) | undefined);
        component?: ReactNode | FC<{
            className?: string | undefined;
            directories: Item[];
        }>;
        emptyResult?: ReactNode | FC;
        loading?: ReactNode | FC;
    };
    footer: {
        component?: ReactNode | FC<{
            menu: boolean;
        }>;
        text?: ReactNode | FC;
    };
    chat: {
        icon?: ReactNode | FC;
        link?: string | undefined;
    };
    darkMode: boolean;
    direction: "ltr" | "rtl";
    docsRepositoryBase: string;
    editLink: {
        component: FC<{
            children: ReactNode;
            className?: string | undefined;
            filePath?: string | undefined;
        }>;
        text?: ReactNode | FC;
    };
    feedback: {
        labels: string;
        useLink: (...args: unknown[]) => string;
        content?: ReactNode | FC;
    };
    i18n: {
        locale: string;
        text: string;
        direction?: "ltr" | "rtl" | undefined;
    }[];
    navbar: {
        component?: ReactNode | FC<NavBarProps>;
        extraContent?: ReactNode | FC;
    };
    nextThemes: {
        defaultTheme: string;
        storageKey: string;
        forcedTheme?: string | undefined;
    };
    notFound: {
        labels: string;
        content?: ReactNode | FC;
    };
    primaryHue: (number | {
        light: number;
        dark: number;
    }) & (number | {
        light: number;
        dark: number;
    } | undefined);
    project: {
        icon?: ReactNode | FC;
        link?: string | undefined;
    };
    serverSideError: {
        labels: string;
        content?: ReactNode | FC;
    };
    sidebar: {
        defaultMenuCollapseLevel: number;
        toggleButton: boolean;
        autoCollapse?: boolean | undefined;
        titleComponent?: ReactNode | FC<{
            title: string;
            type: string;
            route: string;
        }>;
    };
    themeSwitch: {
        useOptions: ({
            system: string;
            light: string;
            dark: string;
        } | ((...args: unknown[]) => {
            system: string;
            light: string;
            dark: string;
        })) & ({
            system: string;
            light: string;
            dark: string;
        } | ((...args: unknown[]) => {
            system: string;
            light: string;
            dark: string;
        }) | undefined);
        component?: ReactNode | FC<{
            lite?: boolean | undefined;
            className?: string | undefined;
        }>;
    };
    toc: {
        float: boolean;
        component?: ReactNode | FC<TOCProps>;
        extraContent?: ReactNode | FC;
        headingComponent?: FC<{
            id: string;
            children: string;
        }> | undefined;
        title?: ReactNode | FC;
    };
    useNextSeoProps: () => NextSeoProps | void;
    components?: Record<string, FC> | undefined;
    faviconGlyph?: string | undefined;
    gitTimestamp?: ReactNode | FC<{
        timestamp: Date;
    }>;
    head?: ReactNode | FC;
    main?: FC<{
        children: ReactNode;
    }> | undefined;
}>;
declare const publicThemeSchema: z.ZodObject<{
    banner: z.ZodOptional<z.ZodObject<{
        dismissible: z.ZodOptional<z.ZodBoolean>;
        key: z.ZodOptional<z.ZodString>;
        text: z.ZodOptional<z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>>;
    }, "strict", z.ZodTypeAny, {
        dismissible?: boolean | undefined;
        key?: string | undefined;
        text?: ReactNode | FC;
    }, {
        dismissible?: boolean | undefined;
        key?: string | undefined;
        text?: ReactNode | FC;
    }>>;
    main: z.ZodOptional<z.ZodOptional<z.ZodType<FC<{
        children: ReactNode;
    }>, z.ZodTypeDef, FC<{
        children: ReactNode;
    }>>>>;
    navigation: z.ZodOptional<z.ZodUnion<[z.ZodBoolean, z.ZodObject<{
        next: z.ZodBoolean;
        prev: z.ZodBoolean;
    }, "strict", z.ZodTypeAny, {
        next: boolean;
        prev: boolean;
    }, {
        next: boolean;
        prev: boolean;
    }>]>>;
    search: z.ZodOptional<z.ZodObject<{
        component: z.ZodOptional<z.ZodType<ReactNode | FC<{
            className?: string | undefined;
            directories: Item[];
        }>, z.ZodTypeDef, ReactNode | FC<{
            className?: string | undefined;
            directories: Item[];
        }>>>;
        emptyResult: z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>;
        error: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodFunction<z.ZodTuple<[], z.ZodUnknown>, z.ZodString>]>>;
        loading: z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>;
        placeholder: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodFunction<z.ZodTuple<[], z.ZodUnknown>, z.ZodString>]>>;
    }, "strict", z.ZodTypeAny, {
        component?: ReactNode | FC<{
            className?: string | undefined;
            directories: Item[];
        }>;
        emptyResult?: ReactNode | FC;
        error?: string | ((...args: unknown[]) => string) | undefined;
        loading?: ReactNode | FC;
        placeholder?: string | ((...args: unknown[]) => string) | undefined;
    }, {
        component?: ReactNode | FC<{
            className?: string | undefined;
            directories: Item[];
        }>;
        emptyResult?: ReactNode | FC;
        error?: string | ((...args: unknown[]) => string) | undefined;
        loading?: ReactNode | FC;
        placeholder?: string | ((...args: unknown[]) => string) | undefined;
    }>>;
    footer: z.ZodOptional<z.ZodObject<{
        component: z.ZodOptional<z.ZodType<ReactNode | FC<{
            menu: boolean;
        }>, z.ZodTypeDef, ReactNode | FC<{
            menu: boolean;
        }>>>;
        text: z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>;
    }, "strict", z.ZodTypeAny, {
        component?: ReactNode | FC<{
            menu: boolean;
        }>;
        text?: ReactNode | FC;
    }, {
        component?: ReactNode | FC<{
            menu: boolean;
        }>;
        text?: ReactNode | FC;
    }>>;
    head: z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>;
    chat: z.ZodOptional<z.ZodObject<{
        icon: z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>;
        link: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    }, "strict", z.ZodTypeAny, {
        icon?: ReactNode | FC;
        link?: string | undefined;
    }, {
        icon?: ReactNode | FC;
        link?: string | undefined;
    }>>;
    components: z.ZodOptional<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodType<FC, z.ZodTypeDef, FC>>>>;
    darkMode: z.ZodOptional<z.ZodBoolean>;
    direction: z.ZodOptional<z.ZodEnum<["ltr", "rtl"]>>;
    docsRepositoryBase: z.ZodOptional<z.ZodString>;
    editLink: z.ZodOptional<z.ZodObject<{
        component: z.ZodOptional<z.ZodType<FC<{
            children: ReactNode;
            className?: string | undefined;
            filePath?: string | undefined;
        }>, z.ZodTypeDef, FC<{
            children: ReactNode;
            className?: string | undefined;
            filePath?: string | undefined;
        }>>>;
        text: z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>;
    }, "strict", z.ZodTypeAny, {
        component?: FC<{
            children: ReactNode;
            className?: string | undefined;
            filePath?: string | undefined;
        }> | undefined;
        text?: ReactNode | FC;
    }, {
        component?: FC<{
            children: ReactNode;
            className?: string | undefined;
            filePath?: string | undefined;
        }> | undefined;
        text?: ReactNode | FC;
    }>>;
    faviconGlyph: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    feedback: z.ZodOptional<z.ZodObject<{
        content: z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>;
        labels: z.ZodOptional<z.ZodString>;
        useLink: z.ZodOptional<z.ZodFunction<z.ZodTuple<[], z.ZodUnknown>, z.ZodString>>;
    }, "strict", z.ZodTypeAny, {
        content?: ReactNode | FC;
        labels?: string | undefined;
        useLink?: ((...args: unknown[]) => string) | undefined;
    }, {
        content?: ReactNode | FC;
        labels?: string | undefined;
        useLink?: ((...args: unknown[]) => string) | undefined;
    }>>;
    gitTimestamp: z.ZodOptional<z.ZodType<ReactNode | FC<{
        timestamp: Date;
    }>, z.ZodTypeDef, ReactNode | FC<{
        timestamp: Date;
    }>>>;
    navbar: z.ZodOptional<z.ZodObject<{
        component: z.ZodOptional<z.ZodType<ReactNode | FC<NavBarProps>, z.ZodTypeDef, ReactNode | FC<NavBarProps>>>;
        extraContent: z.ZodOptional<z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>>;
    }, "strict", z.ZodTypeAny, {
        component?: ReactNode | FC<NavBarProps>;
        extraContent?: ReactNode | FC;
    }, {
        component?: ReactNode | FC<NavBarProps>;
        extraContent?: ReactNode | FC;
    }>>;
    nextThemes: z.ZodOptional<z.ZodObject<{
        defaultTheme: z.ZodOptional<z.ZodString>;
        forcedTheme: z.ZodOptional<z.ZodOptional<z.ZodString>>;
        storageKey: z.ZodOptional<z.ZodString>;
    }, "strict", z.ZodTypeAny, {
        defaultTheme?: string | undefined;
        forcedTheme?: string | undefined;
        storageKey?: string | undefined;
    }, {
        defaultTheme?: string | undefined;
        forcedTheme?: string | undefined;
        storageKey?: string | undefined;
    }>>;
    notFound: z.ZodOptional<z.ZodObject<{
        content: z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>;
        labels: z.ZodOptional<z.ZodString>;
    }, "strict", z.ZodTypeAny, {
        content?: ReactNode | FC;
        labels?: string | undefined;
    }, {
        content?: ReactNode | FC;
        labels?: string | undefined;
    }>>;
    primaryHue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodObject<{
        dark: z.ZodNumber;
        light: z.ZodNumber;
    }, "strict", z.ZodTypeAny, {
        light: number;
        dark: number;
    }, {
        light: number;
        dark: number;
    }>]>>;
    project: z.ZodOptional<z.ZodObject<{
        icon: z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>;
        link: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    }, "strict", z.ZodTypeAny, {
        icon?: ReactNode | FC;
        link?: string | undefined;
    }, {
        icon?: ReactNode | FC;
        link?: string | undefined;
    }>>;
    serverSideError: z.ZodOptional<z.ZodObject<{
        content: z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>;
        labels: z.ZodOptional<z.ZodString>;
    }, "strict", z.ZodTypeAny, {
        content?: ReactNode | FC;
        labels?: string | undefined;
    }, {
        content?: ReactNode | FC;
        labels?: string | undefined;
    }>>;
    sidebar: z.ZodOptional<z.ZodObject<{
        autoCollapse: z.ZodOptional<z.ZodOptional<z.ZodBoolean>>;
        defaultMenuCollapseLevel: z.ZodOptional<z.ZodNumber>;
        titleComponent: z.ZodOptional<z.ZodType<ReactNode | FC<{
            title: string;
            type: string;
            route: string;
        }>, z.ZodTypeDef, ReactNode | FC<{
            title: string;
            type: string;
            route: string;
        }>>>;
        toggleButton: z.ZodOptional<z.ZodBoolean>;
    }, "strict", z.ZodTypeAny, {
        autoCollapse?: boolean | undefined;
        defaultMenuCollapseLevel?: number | undefined;
        titleComponent?: ReactNode | FC<{
            title: string;
            type: string;
            route: string;
        }>;
        toggleButton?: boolean | undefined;
    }, {
        autoCollapse?: boolean | undefined;
        defaultMenuCollapseLevel?: number | undefined;
        titleComponent?: ReactNode | FC<{
            title: string;
            type: string;
            route: string;
        }>;
        toggleButton?: boolean | undefined;
    }>>;
    themeSwitch: z.ZodOptional<z.ZodObject<{
        component: z.ZodOptional<z.ZodType<ReactNode | FC<{
            lite?: boolean | undefined;
            className?: string | undefined;
        }>, z.ZodTypeDef, ReactNode | FC<{
            lite?: boolean | undefined;
            className?: string | undefined;
        }>>>;
        useOptions: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
            light: z.ZodString;
            dark: z.ZodString;
            system: z.ZodString;
        }, "strict", z.ZodTypeAny, {
            system: string;
            light: string;
            dark: string;
        }, {
            system: string;
            light: string;
            dark: string;
        }>, z.ZodFunction<z.ZodTuple<[], z.ZodUnknown>, z.ZodObject<{
            light: z.ZodString;
            dark: z.ZodString;
            system: z.ZodString;
        }, "strict", z.ZodTypeAny, {
            system: string;
            light: string;
            dark: string;
        }, {
            system: string;
            light: string;
            dark: string;
        }>>]>>;
    }, "strict", z.ZodTypeAny, {
        component?: ReactNode | FC<{
            lite?: boolean | undefined;
            className?: string | undefined;
        }>;
        useOptions?: {
            system: string;
            light: string;
            dark: string;
        } | ((...args: unknown[]) => {
            system: string;
            light: string;
            dark: string;
        }) | undefined;
    }, {
        component?: ReactNode | FC<{
            lite?: boolean | undefined;
            className?: string | undefined;
        }>;
        useOptions?: {
            system: string;
            light: string;
            dark: string;
        } | ((...args: unknown[]) => {
            system: string;
            light: string;
            dark: string;
        }) | undefined;
    }>>;
    toc: z.ZodOptional<z.ZodObject<{
        component: z.ZodOptional<z.ZodType<ReactNode | FC<TOCProps>, z.ZodTypeDef, ReactNode | FC<TOCProps>>>;
        extraContent: z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>;
        float: z.ZodOptional<z.ZodBoolean>;
        headingComponent: z.ZodOptional<z.ZodOptional<z.ZodType<FC<{
            id: string;
            children: string;
        }>, z.ZodTypeDef, FC<{
            id: string;
            children: string;
        }>>>>;
        title: z.ZodOptional<z.ZodType<ReactNode | FC, z.ZodTypeDef, ReactNode | FC>>;
    }, "strict", z.ZodTypeAny, {
        component?: ReactNode | FC<TOCProps>;
        extraContent?: ReactNode | FC;
        float?: boolean | undefined;
        headingComponent?: FC<{
            id: string;
            children: string;
        }> | undefined;
        title?: ReactNode | FC;
    }, {
        component?: ReactNode | FC<TOCProps>;
        extraContent?: ReactNode | FC;
        float?: boolean | undefined;
        headingComponent?: FC<{
            id: string;
            children: string;
        }> | undefined;
        title?: ReactNode | FC;
    }>>;
    useNextSeoProps: z.ZodOptional<z.ZodType<() => NextSeoProps | void, z.ZodTypeDef, () => NextSeoProps | void>>;
    i18n: z.ZodOptional<z.ZodArray<z.ZodObject<{
        direction: z.ZodOptional<z.ZodEnum<["ltr", "rtl"]>>;
        locale: z.ZodString;
        text: z.ZodString;
    }, "strict", z.ZodTypeAny, {
        locale: string;
        text: string;
        direction?: "ltr" | "rtl" | undefined;
    }, {
        locale: string;
        text: string;
        direction?: "ltr" | "rtl" | undefined;
    }>, "many">>;
}, "strict", z.ZodTypeAny, {
    banner?: {
        dismissible?: boolean | undefined;
        key?: string | undefined;
        text?: ReactNode | FC;
    } | undefined;
    main?: FC<{
        children: ReactNode;
    }> | undefined;
    navigation?: boolean | {
        next: boolean;
        prev: boolean;
    } | undefined;
    search?: {
        component?: ReactNode | FC<{
            className?: string | undefined;
            directories: Item[];
        }>;
        emptyResult?: ReactNode | FC;
        error?: string | ((...args: unknown[]) => string) | undefined;
        loading?: ReactNode | FC;
        placeholder?: string | ((...args: unknown[]) => string) | undefined;
    } | undefined;
    footer?: {
        component?: ReactNode | FC<{
            menu: boolean;
        }>;
        text?: ReactNode | FC;
    } | undefined;
    head?: ReactNode | FC;
    chat?: {
        icon?: ReactNode | FC;
        link?: string | undefined;
    } | undefined;
    components?: Record<string, FC> | undefined;
    darkMode?: boolean | undefined;
    direction?: "ltr" | "rtl" | undefined;
    docsRepositoryBase?: string | undefined;
    editLink?: {
        component?: FC<{
            children: ReactNode;
            className?: string | undefined;
            filePath?: string | undefined;
        }> | undefined;
        text?: ReactNode | FC;
    } | undefined;
    faviconGlyph?: string | undefined;
    feedback?: {
        content?: ReactNode | FC;
        labels?: string | undefined;
        useLink?: ((...args: unknown[]) => string) | undefined;
    } | undefined;
    gitTimestamp?: ReactNode | FC<{
        timestamp: Date;
    }>;
    navbar?: {
        component?: ReactNode | FC<NavBarProps>;
        extraContent?: ReactNode | FC;
    } | undefined;
    nextThemes?: {
        defaultTheme?: string | undefined;
        forcedTheme?: string | undefined;
        storageKey?: string | undefined;
    } | undefined;
    notFound?: {
        content?: ReactNode | FC;
        labels?: string | undefined;
    } | undefined;
    primaryHue?: number | {
        light: number;
        dark: number;
    } | undefined;
    project?: {
        icon?: ReactNode | FC;
        link?: string | undefined;
    } | undefined;
    serverSideError?: {
        content?: ReactNode | FC;
        labels?: string | undefined;
    } | undefined;
    sidebar?: {
        autoCollapse?: boolean | undefined;
        defaultMenuCollapseLevel?: number | undefined;
        titleComponent?: ReactNode | FC<{
            title: string;
            type: string;
            route: string;
        }>;
        toggleButton?: boolean | undefined;
    } | undefined;
    themeSwitch?: {
        component?: ReactNode | FC<{
            lite?: boolean | undefined;
            className?: string | undefined;
        }>;
        useOptions?: {
            system: string;
            light: string;
            dark: string;
        } | ((...args: unknown[]) => {
            system: string;
            light: string;
            dark: string;
        }) | undefined;
    } | undefined;
    toc?: {
        component?: ReactNode | FC<TOCProps>;
        extraContent?: ReactNode | FC;
        float?: boolean | undefined;
        headingComponent?: FC<{
            id: string;
            children: string;
        }> | undefined;
        title?: ReactNode | FC;
    } | undefined;
    useNextSeoProps?: (() => NextSeoProps | void) | undefined;
    i18n?: {
        locale: string;
        text: string;
        direction?: "ltr" | "rtl" | undefined;
    }[] | undefined;
}, {
    banner?: {
        dismissible?: boolean | undefined;
        key?: string | undefined;
        text?: ReactNode | FC;
    } | undefined;
    main?: FC<{
        children: ReactNode;
    }> | undefined;
    navigation?: boolean | {
        next: boolean;
        prev: boolean;
    } | undefined;
    search?: {
        component?: ReactNode | FC<{
            className?: string | undefined;
            directories: Item[];
        }>;
        emptyResult?: ReactNode | FC;
        error?: string | ((...args: unknown[]) => string) | undefined;
        loading?: ReactNode | FC;
        placeholder?: string | ((...args: unknown[]) => string) | undefined;
    } | undefined;
    footer?: {
        component?: ReactNode | FC<{
            menu: boolean;
        }>;
        text?: ReactNode | FC;
    } | undefined;
    head?: ReactNode | FC;
    chat?: {
        icon?: ReactNode | FC;
        link?: string | undefined;
    } | undefined;
    components?: Record<string, FC> | undefined;
    darkMode?: boolean | undefined;
    direction?: "ltr" | "rtl" | undefined;
    docsRepositoryBase?: string | undefined;
    editLink?: {
        component?: FC<{
            children: ReactNode;
            className?: string | undefined;
            filePath?: string | undefined;
        }> | undefined;
        text?: ReactNode | FC;
    } | undefined;
    faviconGlyph?: string | undefined;
    feedback?: {
        content?: ReactNode | FC;
        labels?: string | undefined;
        useLink?: ((...args: unknown[]) => string) | undefined;
    } | undefined;
    gitTimestamp?: ReactNode | FC<{
        timestamp: Date;
    }>;
    navbar?: {
        component?: ReactNode | FC<NavBarProps>;
        extraContent?: ReactNode | FC;
    } | undefined;
    nextThemes?: {
        defaultTheme?: string | undefined;
        forcedTheme?: string | undefined;
        storageKey?: string | undefined;
    } | undefined;
    notFound?: {
        content?: ReactNode | FC;
        labels?: string | undefined;
    } | undefined;
    primaryHue?: number | {
        light: number;
        dark: number;
    } | undefined;
    project?: {
        icon?: ReactNode | FC;
        link?: string | undefined;
    } | undefined;
    serverSideError?: {
        content?: ReactNode | FC;
        labels?: string | undefined;
    } | undefined;
    sidebar?: {
        autoCollapse?: boolean | undefined;
        defaultMenuCollapseLevel?: number | undefined;
        titleComponent?: ReactNode | FC<{
            title: string;
            type: string;
            route: string;
        }>;
        toggleButton?: boolean | undefined;
    } | undefined;
    themeSwitch?: {
        component?: ReactNode | FC<{
            lite?: boolean | undefined;
            className?: string | undefined;
        }>;
        useOptions?: {
            system: string;
            light: string;
            dark: string;
        } | ((...args: unknown[]) => {
            system: string;
            light: string;
            dark: string;
        }) | undefined;
    } | undefined;
    toc?: {
        component?: ReactNode | FC<TOCProps>;
        extraContent?: ReactNode | FC;
        float?: boolean | undefined;
        headingComponent?: FC<{
            id: string;
            children: string;
        }> | undefined;
        title?: ReactNode | FC;
    } | undefined;
    useNextSeoProps?: (() => NextSeoProps | void) | undefined;
    i18n?: {
        locale: string;
        text: string;
        direction?: "ltr" | "rtl" | undefined;
    }[] | undefined;
}>;
export type DocsThemeConfig = z.infer<typeof themeSchema>;
export type PartialDocsThemeConfig = z.infer<typeof publicThemeSchema>;
export declare const DEFAULT_THEME: DocsThemeConfig;
export declare const DEEP_OBJECT_KEYS: (string | undefined)[];
export {};
